import moment from 'moment';
import {isJSON} from "@/H5Public/utils/authority";
/**
 * 处理字符串相关的函数
 * 2019年9月6日
 * 钟是志
 * */


/**
 * 获取url参数
 */
export function  getUrlParams() {
  let url = window.document.location.href.toString();
  let u = url.split("?");
  if (typeof(u[1]) == "string") {
    u = u[1].split("&");
    let get = {};
    for (let i in u) {
      let j = u[i].split("=");
      get[j[0]] = decodeURIComponent(j[1]);
    }
    return get;
  } else {
    return {};
  }
}

/**
 * 判断是否是JSON字符串 如果是JSON字符串 直接返回 JSON.parse的结果
 * */
export function jsonParse(str) {
  if (typeof str == 'string') {
    try {
      let res = JSON.parse(str);
      if(typeof JSON.parse(str) === 'number'){
        return false;
      }
      return res;
    } catch (e) {
      return false;
    }
  }
}

/**
 * 格式化时间
 * unixTime {string}
 * dateFormat {string}
 * */
export function dateParse(unixTime, dateFormat='YYYY-MM-DD') {
  if(unixTime){
    return moment(unixTime).format(dateFormat);
  }else{
    return '';
  }
}

/**
 * [
 * {
 * "downloadUrl":"http://192.168.1.122:8101/dsf/download?filePath=/u/upload/202009/08151011zzxg.png",
 * "fileExt":"png",
 * "fileName":"首页-系统导览.png",
 * "filePath":"/u/upload/202009/08151011zzxg.png",
 * "id":492,
 * "previewType":"picture",
 * "url":"http://192.168.1.122:8101/dsf/u/upload/202009/08151011zzxg.png",
 * }]
 *
 * */
export function getFileInfo(fileJsonStr) {
  if (!fileJsonStr || !isJSON(fileJsonStr)) {
    if (fileJsonStr && typeof fileJsonStr === 'string' && fileJsonStr.indexOf('http') <= -1 && fileJsonStr.length > 10) {
      // 拼一站式的 图片路径 可能需要修改
      let prefix = window.specialImportantSystemConfig && window.specialImportantSystemConfig.dfs;
      if (fileJsonStr.startsWith('/u/')) { // 一站式的图片
        // console.log('一站式图片地址拼接');
        prefix = window.specialImportantSystemConfig && window.specialImportantSystemConfig.sqlFormsServer;
      }
      return {
        downloadUrl: '',
        url: prefix + fileJsonStr,
        fileName: '',
      };
    } else {
      if (fileJsonStr && typeof fileJsonStr === 'string' && fileJsonStr.indexOf('http') > -1 && fileJsonStr.length > 10) {
        return {
          downloadUrl: '',
          url: fileJsonStr,
          fileName: '',
        };
      } else {
        return {
          downloadUrl: '',
          url: '',
          fileName: '',
        };
      }
    }
  } else {
    if (isJSON(fileJsonStr)) {
      fileJsonStr = JSON.parse(fileJsonStr);
      if (fileJsonStr.url) {
        return fileJsonStr;
      } else {
        return {
          downloadUrl: '',
          url: '',
          fileName: '',
        };
      }
    } else {
      return {
        downloadUrl: '',
        url: '',
        fileName: '',
      };
    }
  }
}
